[![PyPI](https://img.shields.io/pypi/v/runesanalyzer)](https://pypi.org/project/runesanalyzer/) [![Build Status](https://travis-ci.org/clemsciences/runes-analyzer.svg?branch=master)](https://travis-ci.org/clemsciences/runes-analyzer)

# Runes analyzer 

Elder Futhark, Younger Futhark, Short-twig Younger Futhark available
An example of transcription.

To do list:

* use spraakbanken corpus of runic inscriptions and track phonetic evolutions

Source:

* Les causes de la réduction du *futhark* germanique, les glides et le vocalisme. By Alain MAREZ.
